==> lcmaps_1.6.1.orig.tar.gz: lcmaps-1.6.1/src/pluginmanager/lcmaps_arguments.c <==
/**
 * Copyright (c) Members of the EGEE Collaboration. 2004-2010. 
 * See http://www.eu-egee.org/partners/ for details on the copyright
 * holders.  
 * 
 * Licensed under the Apache License, Version 2.0 (the "License"); 
 * you may not use this file except in compliance with the License. 
 * You may obtain a copy of the License at 
 * 
 *     http://www.apache.org/licenses/LICENSE-2.0 
 * 
 * Unless required by applicable law or agreed to in writing, software 
 * distributed under the License is distributed on an "AS IS" BASIS, 
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. 
 * See the License for the specific language governing permissions and 
 * limitations under the License.
 *
 *
 *  Authors:
 *  2009-
 *     Oscar Koeroo <okoeroo@nikhef.nl>
 *     Mischa Sall\'e <msalle@nikhef.nl>
 *     David Groep <davidg@nikhef.nl>
 *     NIKHEF Amsterdam, the Netherlands
 *     <grid-mw-security@nikhef.nl> 
 *
 *  2007-2009
 *     Oscar Koeroo <okoeroo@nikhef.nl>
 *     David Groep <davidg@nikhef.nl>
 *     NIKHEF Amsterdam, the Netherlands
 *
 *  2003-2007
 *     Martijn Steenbakkers <martijn@nikhef.nl>
 *     Gerben Venekamp <venekamp@nikhef.nl>
 *     Oscar Koeroo <okoeroo@nikhef.nl>
 *     David Groep <davidg@nikhef.nl>
 *     NIKHEF Amsterdam, the Netherlands
 *
 */


/*!
    \file   lcmaps_arguments.c
    \author Oscar Koeroo and Martijn Steenbakkers for the EU DataGrid.
    \brief  LCMAPS module for creating and passing introspect/run argument lists

    The interface is composed of:
    -# lcmaps_setArgValue(): Set the value of argument with name argName of argType to value
    -# lcmaps_getArgValue(): Get the value of argument with name argName of argType
    -# lcmaps_findArgName(): Get index of argument with name argName
    -# lcmaps_cntArgs(): Count the number of arguments
*/

/*****************************************************************************
                            Include header files
******************************************************************************/
#include <stdio.h>
#include <stdlib.h>
#include <string.h>

/* LCMAPS includes */
#include "lcmaps_arguments.h"

/******************************************************************************
Function:   lcmaps_setArgValue
Description:
    Fill the "value" field of the argument with name "argName" and type "argType"
    with value.
    The argument list is searched for the combination (argName,argType).

Parameters:
    argName: name of argument
    argType: type of argument
    argcx:   number of arguments
    argvx:   array of arguments structures
Returns:
    0:  success
    -1: failure (could not find structure with name argName)
******************************************************************************/

/*!
    \fn lcmaps_setArgValue(
        char *argName,
        char *argType,
        void *value,
        int argcx,
        lcmaps_argument_t **argvx
        )
    \brief Set the value of argument with name argName of argType to value

    Fill the "value" field of the argument with name "argName" and type "argType"
    with value.
    The argument list is searched for the combination (argName,argType).

    \param argName name of argument
    \param argType type of argument
    \param value   a pointer to the value to which the argument should be set
    \param argcx   number of arguments
    \param argvx   array of arguments structures

    \return 0 in case of succes
*/
int lcmaps_setArgValue(
        char *argName,
        char *argType,
        void *value,
        int argcx,
        lcmaps_argument_t **argvx
)
{
    int argNo = -1;


    /* find the argument name in the introSpect arguments list */
    if ((argNo = lcmaps_findArgNameAndType(argName, argType, argcx, *argvx)) == -1)
        return -1;

    ((*argvx)[argNo]).value = value;
    return 0;
}


/******************************************************************************
Function:   lcmaps_getArgValue
Description:
    Gets the value of argType from values.
    The place within the lcmaps_argument_t values is determined by the argName listed in 
    lcmaps_argument_t *argvx.
    Returns a void pointer to the value.

Parameters:
    argName: name of argument
    argType: type of argument
    argcx:   number of arguments
    argvx:   array of arguments structures
Returns:
    void pointer to the value or NULL
******************************************************************************/

/*!
    \fn lcmaps_getArgValue(
        char *argName,
        char *argType,
        int argcx,
        lcmaps_argument_t *argvx
        )
    \brief Get the value of argument with name argName of argType

    Set the value of argType on the reserved place in values. 
    The place within values is determined by the place where argName is found
    in the arguments list
    Returns a void pointer to the value.

    \param argName name of argument
    \param argType type of argument
    \param argcx   number of arguments
    \param argvx   array of arguments structures

    \return void pointer to the value or NULL
*/
void *lcmaps_getArgValue(
        char *argName,
        char *argType,
        int argcx,
        lcmaps_argument_t *argvx
)
{
    int argNo = -1;

    /* find the argument name in the introSpect arguments list */
    if ((argNo = lcmaps_findArgNameAndType(argName, argType, argcx, argvx)) == -1)
        return NULL;

    return (argvx[argNo].value);
}


/******************************************************************************
Function:   lcmaps_findArgName
Description:
    Search for argName in the arguments list.
    Returns the index to lcmaps_argument_t element.

Parameters:
    argName: name of argument
    argcx:   number of arguments
    argvx:   array of arguments structures
Returns:
    index to lcmaps_argument_t element
******************************************************************************/

/*!
    \fn lcmaps_findArgName(
        char *argName,
        int argcx,
        lcmaps_argument_t *argvx
        )
    \brief Get index of argument with name argName

    Search for argName in the arguments list.
    Returns the index to lcmaps_argument_t element.

    \param argName name of argument
    \param argcx   number of arguments
    \param argvx   array of arguments structures

    \return index to lcmaps_argument_t element
*/
int lcmaps_findArgName(
        char *argName,
        int argcx,
        lcmaps_argument_t *argvx
)
{
    int i = 0;

    for (i = 0; i < argcx; i++)
    {
        if (strcmp(argName, argvx[i].argName) == 0) 
        return i;
    }
    return -1;
}


/******************************************************************************
Function:   lcmaps_findArgNameAndType
Description:
    Search for argName and Type in the arguments list.
    Returns the index to lcmaps_argument_t element.

Parameters:
    argName: name of argument
    argType: type of argument
    argcx:   number of arguments
    argvx:   array of arguments structures
Returns:
    index to lcmaps_argument_t element
******************************************************************************/

/*!
    \fn lcmaps_findArgNameAndType(
        char *argName,
        char *argType,
        int argcx,
        lcmaps_argument_t *argvx
        )
    \brief Get index of argument with name argName

    Search for argName in the arguments list.
    Returns the index to lcmaps_argument_t element.

    \param argName name of argument
    \param argType type of argument
    \param argcx   number of arguments
    \param argvx   array of arguments structures

    \return index to lcmaps_argument_t element
*/
int lcmaps_findArgNameAndType(
        char *argName,
        char *argType,
        int argcx,
        lcmaps_argument_t *argvx
)
{
    int i = 0;

    for (i = 0; i < argcx; i++)
    {
        if ((strcmp(argName, argvx[i].argName) == 0) && 
            (strcmp(argType, argvx[i].argType) == 0))
        return i;
    }
    return -1;
}

/******************************************************************************
Function:   lcmaps_cntArgs
Description:
    Count the number of arguments that are defined in a plug-in
    Returns this number.

Parameters:
    argvx:   array of arguments structures
Returns:
    the number of arguments
******************************************************************************/

/*!
    \fn lcmaps_cntArgs(
        lcmaps_argument_t *argvx
        )
    \brief Count the number of arguments

    Count the number of arguments that are defined in a plug-in
    Returns this number.

    \param argvx   array of arguments structures

    \return the number of arguments
*/
int lcmaps_cntArgs(lcmaps_argument_t *argvx)
{
    int i = 0;

    while (argvx[i].argName != NULL) { i++; }

    return i;
}

==> lcmaps_1.6.6.orig.tar.gz: lcmaps-1.6.6/src/pluginmanager/lcmaps_arguments.c <==
/**
 * Copyright (c) Members of the EGEE Collaboration. 2004-2010. 
 * See http://www.eu-egee.org/partners/ for details on the copyright
 * holders.  
 * 
 * Licensed under the Apache License, Version 2.0 (the "License"); 
 * you may not use this file except in compliance with the License. 
 * You may obtain a copy of the License at 
 * 
 *     http://www.apache.org/licenses/LICENSE-2.0 
 * 
 * Unless required by applicable law or agreed to in writing, software 
 * distributed under the License is distributed on an "AS IS" BASIS, 
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. 
 * See the License for the specific language governing permissions and 
 * limitations under the License.
 *
 *
 *  Authors:
 *  2009-
 *     Oscar Koeroo <okoeroo@nikhef.nl>
 *     Mischa Sall\'e <msalle@nikhef.nl>
 *     David Groep <davidg@nikhef.nl>
 *     NIKHEF Amsterdam, the Netherlands
 *     <grid-mw-security@nikhef.nl> 
 *
 *  2007-2009
 *     Oscar Koeroo <okoeroo@nikhef.nl>
 *     David Groep <davidg@nikhef.nl>
 *     NIKHEF Amsterdam, the Netherlands
 *
 *  2003-2007
 *     Martijn Steenbakkers <martijn@nikhef.nl>
 *     Gerben Venekamp <venekamp@nikhef.nl>
 *     Oscar Koeroo <okoeroo@nikhef.nl>
 *     David Groep <davidg@nikhef.nl>
 *     NIKHEF Amsterdam, the Netherlands
 *
 */


/*!
    \file   lcmaps_arguments.c
    \author Oscar Koeroo and Martijn Steenbakkers for the EU DataGrid.
    \brief  LCMAPS module for creating and passing introspect/run argument lists

    The interface is composed of:
    -# lcmaps_setArgValue(): Set the value of argument with name argName of argType to value
    -# lcmaps_getArgValue(): Get the value of argument with name argName of argType
    -# lcmaps_findArgName(): Get index of argument with name argName
    -# lcmaps_cntArgs(): Count the number of arguments
*/

/*****************************************************************************
                            Include header files
******************************************************************************/
/* Needed for NULL */
#include <stdio.h>
#include <string.h>

/* LCMAPS includes */
#include "lcmaps_arguments.h"

/******************************************************************************
Function:   lcmaps_setArgValue
Description:
    Fill the "value" field of the argument with name "argName" and type "argType"
    with value.
    The argument list is searched for the combination (argName,argType).

Parameters:
    argName: name of argument
    argType: type of argument
    argcx:   number of arguments
    argvx:   array of arguments structures
Returns:
    0:  success
    -1: failure (could not find structure with name argName)
******************************************************************************/

/*!
    \fn lcmaps_setArgValue(
        const char *argName,
        const char *argType,
        void *value,
        int argcx,
        lcmaps_argument_t **argvx
        )
    \brief Set the value of argument with name argName of argType to value

    Fill the "value" field of the argument with name "argName" and type "argType"
    with value.
    The argument list is searched for the combination (argName,argType).

    \param argName name of argument
    \param argType type of argument
    \param value   a pointer to the value to which the argument should be set
    \param argcx   number of arguments
    \param argvx   array of arguments structures

    \return 0 in case of succes
*/
int lcmaps_setArgValue(
        const char *argName,
        const char *argType,
        void *value,
        int argcx,
        lcmaps_argument_t **argvx
)
{
    int argNo = -1;


    /* find the argument name in the introSpect arguments list */
    if ((argNo = lcmaps_findArgNameAndType(argName, argType, argcx, *argvx)) == -1)
        return -1;

    ((*argvx)[argNo]).value = value;
    return 0;
}


/******************************************************************************
Function:   lcmaps_getArgValue
Description:
    Gets the value of argType from values.
    The place within the lcmaps_argument_t values is determined by the argName listed in 
    lcmaps_argument_t *argvx.
    Returns a void pointer to the value.

Parameters:
    argName: name of argument
    argType: type of argument
    argcx:   number of arguments
    argvx:   array of arguments structures
Returns:
    void pointer to the value or NULL
******************************************************************************/

/*!
    \fn lcmaps_getArgValue(
        const char *argName,
        const char *argType,
        int argcx,
        lcmaps_argument_t *argvx
        )
    \brief Get the value of argument with name argName of argType

    Set the value of argType on the reserved place in values. 
    The place within values is determined by the place where argName is found
    in the arguments list
    Returns a void pointer to the value.

    \param argName name of argument
    \param argType type of argument
    \param argcx   number of arguments
    \param argvx   array of arguments structures

    \return void pointer to the value or NULL
*/
void *lcmaps_getArgValue(
        const char *argName,
        const char *argType,
        int argcx,
        lcmaps_argument_t *argvx
)
{
    int argNo = -1;

    /* find the argument name in the introSpect arguments list */
    if ((argNo = lcmaps_findArgNameAndType(argName, argType, argcx, argvx)) == -1)
        return NULL;

    return (argvx[argNo].value);
}


/******************************************************************************
Function:   lcmaps_findArgName
Description:
    Search for argName in the arguments list.
    Returns the index to lcmaps_argument_t element.

Parameters:
    argName: name of argument
    argcx:   number of arguments
    argvx:   array of arguments structures
Returns:
    index to lcmaps_argument_t element
******************************************************************************/

/*!
    \fn lcmaps_findArgName(
        const char *argName,
        int argcx,
        lcmaps_argument_t *argvx
        )
    \brief Get index of argument with name argName

    Search for argName in the arguments list.
    Returns the index to lcmaps_argument_t element.

    \param argName name of argument
    \param argcx   number of arguments
    \param argvx   array of arguments structures

    \return index to lcmaps_argument_t element
*/
int lcmaps_findArgName(
        const char *argName,
        int argcx,
        lcmaps_argument_t *argvx
)
{
    int i = 0;

    for (i = 0; i < argcx; i++)
    {
        if (strcmp(argName, argvx[i].argName) == 0) 
        return i;
    }
    return -1;
}


/******************************************************************************
Function:   lcmaps_findArgNameAndType
Description:
    Search for argName and Type in the arguments list.
    Returns the index to lcmaps_argument_t element.

Parameters:
    argName: name of argument
    argType: type of argument
    argcx:   number of arguments
    argvx:   array of arguments structures
Returns:
    index to lcmaps_argument_t element
******************************************************************************/

/*!
    \fn lcmaps_findArgNameAndType(
        const char *argName,
        const char *argType,
        int argcx,
        lcmaps_argument_t *argvx
        )
    \brief Get index of argument with name argName

    Search for argName in the arguments list.
    Returns the index to lcmaps_argument_t element.

    \param argName name of argument
    \param argType type of argument
    \param argcx   number of arguments
    \param argvx   array of arguments structures

    \return index to lcmaps_argument_t element
*/
int lcmaps_findArgNameAndType(
        const char *argName,
        const char *argType,
        int argcx,
        lcmaps_argument_t *argvx
)
{
    int i = 0;

    for (i = 0; i < argcx; i++)
    {
        if ((strcmp(argName, argvx[i].argName) == 0) && 
            (strcmp(argType, argvx[i].argType) == 0))
        return i;
    }
    return -1;
}

/******************************************************************************
Function:   lcmaps_cntArgs
Description:
    Count the number of arguments that are defined in a plug-in
    Returns this number.

Parameters:
    argvx:   array of arguments structures
Returns:
    the number of arguments
******************************************************************************/

/*!
    \fn lcmaps_cntArgs(
        lcmaps_argument_t *argvx
        )
    \brief Count the number of arguments

    Count the number of arguments that are defined in a plug-in
    Returns this number.

    \param argvx   array of arguments structures

    \return the number of arguments
*/
int lcmaps_cntArgs(lcmaps_argument_t *argvx)
{
    int i = 0;

    while (argvx[i].argName != NULL) { i++; }

    return i;
}
